# Models

Aoa Models Repository. 

*Replace with relevant description.* 

Refer to the [Official Documentation](https://docs.tdaoa.com) for more information.

# Available Models

More human friendly folder names for each model under model_definitions is tracked in [issue-105](https://github.com/ThinkBigAnalytics/AoaCoreService/issues/105).

